``canvas`` argument now required for ``FigureFrameWx``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
``FigureFrameWx`` now requires a keyword-only ``canvas`` argument
when it is constructed.
